@@ -1,9 +1,9 @@
 package Bencher::Scenario::Example::CommandNotFound;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-31'; # DATE
+our $DATE = '2021-08-13'; # DATE
 our $DIST = 'Bencher-Backend'; # DIST
-our $VERSION = '1.059'; # VERSION
+our $VERSION = '1.060'; # VERSION
 
 our $scenario = {
     participants => [
@@ -30,7 +30,7 @@ Bencher::Scenario::Example::CommandNotFound - An example scenario: command not f
 
 =head1 VERSION
 
-This document describes version 1.059 of Bencher::Scenario::Example::CommandNotFound (from Perl distribution Bencher-Backend), released on 2021-07-31.
+This document describes version 1.060 of Bencher::Scenario::Example::CommandNotFound (from Perl distribution Bencher-Backend), released on 2021-08-13.
 
 =head1 SYNOPSIS
 
@@ -56,9 +56,26 @@ feature.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
